<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="th">
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="50"/>
        <source>Cooperation</source>
        <translation>ความร่วมมือ</translation>
    </message>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="54"/>
        <source>Cooperation is a powerful cross-terminal office tool that helps you deliver files, share keys and mice, and share clipboards between different devices.</source>
        <translation>ความร่วมมือเป็นเครื่องมือสำหรับการทำงานในองค์กรที่ทรงพลัง ช่วยให้คุณส่งไฟล์ แบ่งปันคีย์และเมาส์ และแบ่งปันคลิปบอร์ดระหว่างอุปกรณ์ต่างๆ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="69"/>
        <source>File transfer settings</source>
        <translation>การตั้งค่าการส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="71"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>ตั้งค่า</translation>
    </message>
</context>
<context>
    <name>cooperation_core::BottomLabel</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
        <source>Local IP: %1</source>
        <translation>IPท้องถิ่น: %1</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; ได้ส่งไฟล์มาให้คุณ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>ปฏิเสธ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="35"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>ยอมรับ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationSearchEdit</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/cooperationsearchedit.cpp" line="34"/>
        <source>Search</source>
        <translation>ค้นหา</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTaskDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>ยกเลิก</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="134"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>ลองอีกครั้ง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="157"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>ปฏิเสธ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="160"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>ยอมรับ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="184"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>ปิด</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTransDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="275"/>
        <source>File Transfer</source>
        <translation>การส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="278"/>
        <source>File transfer</source>
        <translation>การส่งไฟล์</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationUtil</name>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="217"/>
        <source>View Help Manual</source>
        <translation>ดูคู่มือการใช้งาน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="218"/>
        <source>Welcome to dde-cooperation</source>
        <translation>ยินดีต้อนรับสู่ dde-cooperation</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>Keyboard and mouse sharing</source>
        <translation>การแบ่งปันคีย์และเมาส์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
        <translation>เมื่อมีการเชื่อมต่อระหว่างอุปกรณ์สองเครื่อง คีย์และเมาส์ของผู้เริ่มต้นสามารถใช้ควบคุมอุปกรณ์อีกเครื่องหนึ่งได้</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Clipboard sharing</source>
        <translation>การแบ่งปันคลิปบอร์ด</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Once a connection is made between two devices, the clipboard will be shared and can be copied on one device and pasted on the other device</source>
        <translation>เมื่อมีการเชื่อมต่อระหว่างอุปกรณ์สองเครื่อง คลิปบอร์ดจะถูกแบ่งปันและสามารถคัดลอกได้ในอุปกรณ์หนึ่ง และวางได้อีกอุปกรณ์หนึ่ง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>Delivery of documents</source>
        <translation>การส่งเอกสาร</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>After connecting between two devices, you can initiate a file delivery to the other device</source>
        <translation>หลังจากเชื่อมต่อระหว่างอุปกรณ์สองเครื่อง คุณสามารถเริ่มต้นการส่งไฟล์ไปยังอุปกรณ์อีกเครื่องหนึ่งได้</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>For detailed instructions, please click on the Help Manual below</source>
        <translation>เพื่อข้อมูลเชิงลึก โปรดคลิกที่คู่มือการใช้งานด้านล่าง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>Usage</source>
        <translation>การใช้งาน</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DeviceItem</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="191"/>
        <source>connected</source>
        <translation>เชื่อมต่อแล้ว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="197"/>
        <source>connectable</source>
        <translation>สามารถเชื่อมต่อได้</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="204"/>
        <source>offline</source>
        <translation>ออนไลน์</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DiscoverController</name>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="245"/>
        <source>Confirm</source>
        <translation>ยืนยัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="246"/>
        <source>Close</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
        <source>Please click to confirm to enable the LAN discovery service!</source>
        <translation>กรุณาคลิกเพื่อยืนยันการเปิดใช้งานบริการค้นหาผ่านเครือข่าย LAN!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="249"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned on</source>
        <translation>ไม่สามารถค้นหาและถูกค้นหาโดยอุปกรณ์อื่นได้หากไม่ได้เปิดใช้งานการค้นหาผ่านเครือข่าย LAN</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
        <translation>ไม่สามารถค้นหาและถูกค้นหาโดยอุปกรณ์อื่นได้หากไม่ได้เปิดใช้งานการค้นหาผ่านเครือข่าย LAN คลิกขวาที่เมนู Start ของ Windows -&gt; Computer Management -&gt; Services and Applications -&gt; Services เพื่อเปิดใช้งานบริการ Bonjour</translation>
    </message>
</context>
<context>
    <name>cooperation_core::FirstTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="126"/>
        <source>First step</source>
        <translation>ขั้นตอนแรก</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="127"/>
        <source>The opposite end opens the application and connects to the same network</source>
        <translation>อีกฝั่งหนึ่งเปิดแอปพลิเคชันและเชื่อมต่อกับเครือข่ายเดียวกัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="128"/>
        <source>Second step</source>
        <translation>ขั้นตอนที่สอง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="130"/>
        <source>Third step</source>
        <translation>ขั้นตอนที่สาม</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="189"/>
        <source>to send the file</source>
        <translation>เพื่อส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="196"/>
        <source>to connect to the peer device</source>
        <translation>เพื่อเชื่อมต่อกับอุปกรณ์คู่</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="129"/>
        <source>Enter the peer IP in the search box</source>
        <translation>กรอก IP ของอุปกรณ์คู่ในช่องค้นหา</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="131"/>
        <source>Click</source>
        <translation>คลิก</translation>
    </message>
</context>
<context>
    <name>cooperation_core::InformationDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="153"/>
        <source>OK</source>
        <translation>ตกลง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
        <source>the file save location is invalid</source>
        <translation>ตำแหน่งการบันทึกไฟล์ไม่ถูกต้อง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="172"/>
        <source>This path is a read-only directory. Please choose a different location for saving the file.</source>
        <translation>เส้นทางนี้เป็นโฟลเดอร์ที่อ่าน-only กรุณาเลือกตำแหน่งอื่นสำหรับการบันทึกไฟล์</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LockScreenWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="204"/>
        <source>The current device has been locked</source>
        <translation>อุปกรณ์ปัจจุบันถูกล็อกแล้ว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="207"/>
        <source>You can unlock it on mobile devices</source>
        <translation>คุณสามารถปลดล็อกได้ผ่านอุปกรณ์มือถือ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LookingForDeviceWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="81"/>
        <source>Looking for devices</source>
        <translation>กำลังค้นหาอุปกรณ์</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindow</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="266"/>
        <source>Minimise to system tray</source>
        <translation>ลดขนาดลงที่ระบบ tray</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="268"/>
        <source>Exit</source>
        <translation>ออก</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="277"/>
        <source>No more enquiries</source>
        <translation>ไม่มีการสอบถามเพิ่มเติม</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
        <source>Cancel</source>
        <translation>ยกเลิก</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
        <source>Confirm</source>
        <translation>ยืนยัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
        <source>Please select your operation</source>
        <translation>กรุณาเลือกการดำเนินการของคุณ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="338"/>
        <source>Restore</source>
        <translation>กู้คืน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="339"/>
        <source>Quit</source>
        <translation>ออกจากโปรแกรม</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="62"/>
        <source>Computer</source>
        <translation>คอมพิวเตอร์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="63"/>
        <source>Phone</source>
        <translation>โทรศัพท์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="74"/>
        <source>Selection of delivery device</source>
        <translation>การเลือกอุปกรณ์ส่ง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
        <source>Settings</source>
        <translation>ตั้งค่า</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="88"/>
        <source>Download client</source>
        <translation>ดาวน์โหลดไคลเอนต์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="130"/>
        <source>Download Windows client</source>
        <translation>ดาวน์โหลดไคลเอนต์ Windows</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoNetworkWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="150"/>
        <source>Please connect to the network</source>
        <translation>กรุณาเชื่อมต่อเครือข่าย</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="185"/>
        <source>1. Enable cross-end collaborative applications. Applications on the UOS can be downloaded from the App Store, and applications on the Windows side can be downloaded from: </source>
        <translation>1. เปิดใช้งานแอปพลิเคชันการทำงานร่วมกันข้ามอุปกรณ์ แอปพลิเคชันบนระบบ UOS สามารถดาวน์โหลดได้จากแอปสโตร์ และแอปพลิเคชันบนด้าน Windows สามารถดาวน์โหลดได้จาก: </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="199"/>
        <source>2. On the same LAN as the device</source>
        <translation>2. อยู่ในเครือข่าย LAN เดียวกันกับอุปกรณ์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
        <translation>3. ไฟล์มานเนอร์-ตั้งค่า-การวางไฟล์-อนุญาตให้ผู้ใช้ต่อไปนี้วางไฟล์ไปยังฉัน -&quot;ทุกคนในเครือข่าย LAN เดียวกัน&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
        <translation>3. ตั้งค่า-ตั้งค่าพื้นฐาน-โหมดค้นหา-&quot;อนุญาตให้ทุกคนในเครือข่าย LAN เดียวกัน&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
        <source>4. Try entering the target device IP in the top search box</source>
        <translation>4. ลองป้อน IP ของอุปกรณ์เป้าหมายในกล่องค้นหาด้านบน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="216"/>
        <source>Unable to find collaborative device？</source>
        <translation>ไม่สามารถค้นหาอุปกรณ์การทำงานร่วมกันได้？</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="245"/>
        <source>1. The mobile phone needs to download cross end collaborative applications.</source>
        <translation>1. โทรศัพท์มือถือต้องดาวน์โหลดแอปพลิเคชันการทำงานร่วมกันข้ามอุปกรณ์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
        <source>Go to download&gt;</source>
        <translation>ไปดาวน์โหลด&gt;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
        <source>2. After installation, scan the code to connect to this device for collaboration.</source>
        <translation>2. หลังจากติดตั้งแล้ว ให้สแกนโค้ดเพื่อเชื่อมต่ออุปกรณ์นี้เพื่อการทำงานร่วมกัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="251"/>
        <source>3. After connecting this device, the mobile end needs to keep cross end collaborative applications open and on the same LAN as this device</source>
        <translation>3. หลังจากเชื่อมต่ออุปกรณ์นี้แล้ว ปลายทางมือถือต้องเปิดแอปพลิเคชันการทำงานร่วมกันข้ามอุปกรณ์ไว้ และอยู่ในเครือข่าย LAN เดียวกันกับอุปกรณ์นี้</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="253"/>
        <source>Instructions for use</source>
        <translation>คำแนะนำการใช้งาน</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="293"/>
        <source>No device found</source>
        <translation>ไม่พบอุปกรณ์ใด ๆ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::PhoneHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="65"/>
        <source>Disconnect</source>
        <translation>ตัดการเชื่อมต่อ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="93"/>
        <source>“%1”apply to initiate screen casting</source>
        <translation>“%1” ใช้เพื่อเริ่มการถ่ายภาพหน้าจอ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
        <source>cancel</source>
        <translation>ยกเลิก</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
        <source>comfirm</source>
        <translation>ยืนยัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="139"/>
        <source>“%1”connection disconnected!</source>
        <translation>“%1” ถูกตัดการเชื่อมต่อ!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
        <translation>คุณแน่ใจว่าจะตัดการเชื่อมต่อและร่วมงานกับ &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
        <source>disconnect</source>
        <translation>ตัดการเชื่อมต่อ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ProgressWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="115"/>
        <source>Remaining time %1 | %2%</source>
        <translation>เวลาคงเหลือ %1 | %2%</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="133"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>ยกเลิก</translation>
    </message>
</context>
<context>
    <name>cooperation_core::QRCodeWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="102"/>
        <source>Scan code connection</source>
        <translation>การเชื่อมต่อผ่านการสแกนโค้ด</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="108"/>
        <source>Please use the cross end collaboration app to scan the code</source>
        <translation>กรุณาใช้แอปพลิเคชันการทำงานร่วมกันข้ามอุปกรณ์เพื่อสแกนโค้ด</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="114"/>
        <source>Mobile phones and devices need to be connected to the same local area network</source>
        <translation>โทรศัพท์มือถือและอุปกรณ์ต้องเชื่อมต่อเข้ากับเครือข่ายพื้นที่ท้องถิ่นเดียวกัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="147"/>
        <source>Click to download UOS assistant APP</source>
        <translation>คลิกเพื่อดาวน์โหลดแอปพลิเคชันผู้ช่วย UOS</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="179"/>
        <source>Ok</source>
        <comment>button</comment>
        <translation>ตกลง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="182"/>
        <source>View</source>
        <comment>button</comment>
        <translation>ดู</translation>
    </message>
</context>
<context>
    <name>cooperation_core::SettingDialogPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
        <source>Everyone in the same LAN</source>
        <translation>ทุกคนในเครือข่าย LAN เดียวกัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
        <source>Not allow</source>
        <translation>ไม่อนุญาต</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="50"/>
        <source>Screen right</source>
        <translation>จอภาพด้านขวา</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="51"/>
        <source>Screen left</source>
        <translation>จอภาพด้านซ้าย</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="54"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>อนุญาตเฉพาะผู้ที่กำลังร่วมงานเท่านั้น</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="132"/>
        <source>Basic Settings</source>
        <translation>การตั้งค่าพื้นฐาน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="143"/>
        <source>Discovery mode</source>
        <translation>โหมดค้นหา</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
        <translation>อุปกรณ์อื่นสามารถค้นหาและเชื่อมต่อกับคุณผ่านแอป &quot;Cooperation&quot; ได้</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
        <source>Device name</source>
        <translation>ชื่ออุปกรณ์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="213"/>
        <source>Peripheral share</source>
        <translation>การแบ่งปันอุปกรณ์เสริม</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="215"/>
        <source>Allows peripherals that have been established to collaborate across devices to control this device, including keyboard, mouse, trackpad, etc</source>
        <translation>อนุญาตให้อุปกรณ์เสริมที่ได้จัดตั้งไว้ร่วมงานกับอุปกรณ์อื่นสามารถควบคุมอุปกรณ์นี้ได้ รวมถึงแป้นพิมพ์ หนู แท็ปเพด เป็นต้น</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="224"/>
        <source>When this device is the connected party, the mouse penetrates from the screen of this device to the position of the connected party</source>
        <translation>เมื่ออุปกรณ์นี้เป็นฝ่ายที่ถูกเชื่อมต่อ หนูจะทะลุจากหน้าจออุปกรณ์นี้ไปยังตำแหน่งของฝ่ายที่เชื่อมต่อ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="254"/>
        <source>Connection direction</source>
        <translation>ทิศทางการเชื่อมต่อ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="273"/>
        <source>Allows the following users to send files to me</source>
        <translation>อนุญาตให้ผู้ใช้ต่อไปนี้ส่งไฟล์มาที่ฉัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="280"/>
        <source>File save location</source>
        <translation>ตำแหน่งการบันทึกไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="296"/>
        <source>Share clipboard</source>
        <translation>แบ่งปันแผงคัดลอก</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="298"/>
        <source>When sharing is enabled on the server (the connected device), the clipboard will be shared between the two computers</source>
        <translation>เมื่อการแบ่งปันถูกเปิดใช้งานบนเซิร์ฟเวอร์ (อุปกรณ์ที่เชื่อมต่อ) แผงคัดลอกจะถูกแบ่งปันระหว่างสองเครื่องคอมพิวเตอร์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="355"/>
        <source>The device name must contain 1 to 20 characters</source>
        <translation>ชื่ออุปกรณ์ต้องมีตัวอักษร 1 ถึง 20 ตัว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="362"/>
        <source>The device name must contain 1 to 63 characters</source>
        <translation>ชื่ออุปกรณ์ต้องมีตัวอักษร 1 ถึง 63 ตัว</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="238"/>
        <source>connect</source>
        <translation>เชื่อมต่อ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="246"/>
        <source>Disconnect</source>
        <translation>ตัดการเชื่อมต่อ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
        <source>Unable to collaborate to &quot;%1&quot;</source>
        <translation>ไม่สามารถร่วมทำงานกับ &quot;%1&quot; ได้</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
        <source>You are connecting to another device</source>
        <translation>คุณกำลังเชื่อมต่อกับอุปกรณ์อื่น</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
        <source>Requesting collaborate to &quot;%1&quot;</source>
        <translation>กำลังขอร่วมทำงานกับ &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
        <source>Coordination with &quot;%1&quot; has ended</source>
        <translation>การประสานงานกับ &quot;%1&quot; ได้สิ้นสุดแล้ว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
        <translation>ได้รับคำขอร่วมทำงานข้ามอุปกรณ์จาก &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
        <source>Reject</source>
        <translation>ปฏิเสธ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="355"/>
        <source>Accept</source>
        <translation>ยอมรับ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="374"/>
        <source>Cooperation</source>
        <translation>การร่วมมือ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>การเชื่อมต่อกับ &quot;%1&quot; ล้มเหลว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
        <source>Unable to collaborate</source>
        <translation>ไม่สามารถทำงานร่วมกันได้</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="419"/>
        <source>Failed to run process!</source>
        <translation>ไม่สามารถดำเนินการกระบวนการได้!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
        <translation>เชื่อมต่อสำเร็จ กำลังประสานงานกับ &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
        <source>&quot;%1&quot; has rejected your request for collaboration</source>
        <translation>&quot;%1&quot; ปฏิเสธคำขอการทำงานร่วมกันของคุณ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
        <source>&quot;%1&quot; is connecting with other devices</source>
        <translation>&quot;%1&quot; กำลังเชื่อมต่อกับอุปกรณ์อื่น</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
        <translation>คำขอเชื่อมต่อที่ &quot;%1&quot; ส่งมาถึงคุณถูกตัดขาดเนื่องจากเกิดการรอจนถึงเวลาหมด</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
        <source>The other party does not confirm, please try again later</source>
        <translation>ฝ่ายตรงข้ามยังไม่ยืนยัน โปรดลองอีกครั้งในภายหลัง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="524"/>
        <source>The other party has cancelled the connection request !</source>
        <translation>ฝ่ายตรงข้ามได้ยกเลิกคำขอเชื่อมต่อ!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="528"/>
        <source>connect failed</source>
        <translation>การเชื่อมต่อล้มเหลว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="538"/>
        <source>Network not connected, file delivery failed this time.                               Please connect to the network and try again!</source>
        <translation>เครือข่ายไม่เชื่อมต่อ จึงส่งไฟล์ล้มเหลวในครั้งนี้ โปรดเชื่อมต่อกับเครือข่ายและลองอีกครั้ง!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="545"/>
        <source>File transfer failed</source>
        <translation>การส่งไฟล์ล้มเหลว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="547"/>
        <source>Network not connected, file delivery failed this time.                                           Please connect to the network and try again!</source>
        <translation>เครือข่ายไม่เชื่อมต่อ จึงส่งไฟล์ล้มเหลวในครั้งนี้ โปรดเชื่อมต่อกับเครือข่ายและลองอีกครั้ง!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="562"/>
        <source>Network exception</source>
        <translation>เกิดข้อผิดพลาดของเครือข่าย</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
        <source>Please check the network &quot;%1&quot;</source>
        <translation>กรุณาตรวจสอบเครือข่าย &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
        <source>Cooperation</source>
        <translation>การทำงานร่วมกัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
        <source>Connection successful, coordinating with &quot;%1&quot;</source>
        <translation>เชื่อมต่อสำเร็จ กำลังประสานงานกับ &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>การเชื่อมต่อ &quot;%1&quot; ล้มเหลว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
        <source>File read/write exception</source>
        <translation>เกิดข้อผิดพลาดในการอ่าน/เขียนไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
        <source>The other party has canceled the file transfer</source>
        <translation>ฝ่ายตรงข้ามได้ยกเลิกการส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
        <source>File sent successfully</source>
        <translation>ไฟล์ถูกส่งสำเร็จ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="168"/>
        <source>View transfer history</source>
        <translation>ดูประวัติการส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="177"/>
        <source>Send files</source>
        <translation>ส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="302"/>
        <source>The other party did not receive, the files failed to send</source>
        <translation>ฝ่ายตรงข้ามไม่ได้รับ ไฟล์จึงส่งล้มเหลว</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="332"/>
        <source>Cancel</source>
        <translation>ยกเลิก</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="335"/>
        <source>File receiving %1% | Remaining time %2</source>
        <translation>กำลังรับไฟล์ %1% | เวลาคงเหลือ %2</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Sending files to &quot;%1&quot;</source>
        <translation>กำลังส่งไฟล์ไปยัง &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Receiving files from &quot;%1&quot;</source>
        <translation>กำลังรับไฟล์จาก &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
        <source>Reject</source>
        <translation>ปฏิเสธ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="400"/>
        <source>Accept</source>
        <translation>ยอมรับ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="401"/>
        <source>Close</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; ส่งไฟล์บางส่วนมาให้คุณ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
        <source>View</source>
        <translation>ดู</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="412"/>
        <source>The other party has cancelled the transfer request !</source>
        <translation>อีกฝ่ายได้ยกเลิกคำขอส่งไฟล์แล้ว !</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
        <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
        <translation>&gt;-
 ไม่มีพื้นที่จัดเก็บไฟล์เพียงพอ ไฟล์ส่งไม่สำเร็จในครั้งนี้ โปรดทำความสะอาดพื้นที่จัดเก็บและลองอีกครั้ง!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
        <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
        <translation>&gt;-
 ไม่ได้เชื่อมต่อกับเครือข่าย ไฟล์ส่งไม่สำเร็จในครั้งนี้ โปรดเชื่อมต่อกับเครือข่ายและลองอีกครั้ง!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="554"/>
        <source>calculating</source>
        <translation>กำลังคำนวณ</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="563"/>
        <source>The other party rejects your request</source>
        <translation>อีกฝ่ายปฏิเสธคำขอของคุณ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="132"/>
        <source>File transfer</source>
        <translation>การส่งไฟล์</translation>
    </message>
</context>
<context>
    <name>cooperation_core::VncViewer</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
        <source>Disconnected</source>
        <translation>ถูกตัดการเชื่อมต่อ</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WaitConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="75"/>
        <source>File Transfer</source>
        <translation>การส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="91"/>
        <source>Wait for confirmation...</source>
        <translation>รอการยืนยัน...</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WorkspaceWidgetPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
        <source>Please enter the device ip/name of the collaborator</source>
        <translation>กรุณาป้อนอีพี/ชื่อของอุปกรณ์ที่ทำงานร่วมกัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="56"/>
        <source>Nearby Device</source>
        <translation>อุปกรณ์ใกล้เคียง</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="72"/>
        <source>Re-scan for devices</source>
        <translation>สแกนอุปกรณ์อีกครั้ง</translation>
    </message>
</context>
<context>
    <name>cooperation_transfer::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/transfer/helper/transferhelper.cpp" line="105"/>
        <source>Send files</source>
        <translation>ส่งไฟล์</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/menu/cooperationmenuscene.cpp" line="34"/>
        <source>File transfer</source>
        <translation>การส่งไฟล์</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="64"/>
        <source>File transfer</source>
        <translation>การส่งไฟล์</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="154"/>
        <source>File transfer settings</source>
        <translation>การตั้งค่าการส่งไฟล์</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>Everyone in the same LAN</source>
        <translation>ทุกคนในเครือข่าย LAN เดียวกัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="172"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>อนุญาตเฉพาะผู้ที่ทำงานร่วมกันเท่านั้น</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="173"/>
        <source>Not allow</source>
        <translation>ห้าม</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="178"/>
        <source>Allows the following users to send files to me</source>
        <translation>อนุญาตให้ผู้ใช้ต่อไปนี้ส่งไฟล์มาให้ฉัน</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="179"/>
        <source>File save location</source>
        <translation>ตำแหน่งการบันทึกไฟล์</translation>
    </message>
</context>
</TS>